@@ -4,12 +4,12 @@
 # pylint:disable=unused-import
 import time
 import board
-import busio
 from adafruit_ltr390 import LTR390, UV, ALS
 
 THRESHOLD_VALUE = 100
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 ltr = LTR390(i2c)
 
 ltr.high_threshold = THRESHOLD_VALUE
